summaryrefslogtreecommitdiffstats
path: root/tools/src/h5import/h5import.c
diff options
context:
space:
mode:
authorAllen Byrne <byrn@hdfgroup.org>2018-02-05 18:38:20 (GMT)
committerAllen Byrne <byrn@hdfgroup.org>2018-02-05 18:38:20 (GMT)
commitf325002db905f7da14e66a3bb30ac508d0cfb7fa (patch)
treee5bab0dc30cdeee8d4e4e0c5c899bd4c32e1ca71 /tools/src/h5import/h5import.c
parentffa2dec25d69ba2d530c5eb60e07d6618562017a (diff)
downloadhdf5-f325002db905f7da14e66a3bb30ac508d0cfb7fa.zip
hdf5-f325002db905f7da14e66a3bb30ac508d0cfb7fa.tar.gz
hdf5-f325002db905f7da14e66a3bb30ac508d0cfb7fa.tar.bz2
HDFFV-10345 spelling errors
Diffstat (limited to 'tools/src/h5import/h5import.c')
-rw-r--r--tools/src/h5import/h5import.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/src/h5import/h5import.c b/tools/src/h5import/h5import.c
index 36a8c21..76e78af 100644
--- a/tools/src/h5import/h5import.c
+++ b/tools/src/h5import/h5import.c
@@ -1405,7 +1405,7 @@ static int processConfigurationFile(char *infile, struct Input *in)
const char *err14a = "COMPRESSION-PARAM keyword appears twice in %s.\n";
const char *err14b = "Error in retrieving the compression parameter from %s.\n";
const char *err15a = "EXTERNAL-STORAGE keyword appears twice in %s.\n";
- const char *err15b = "Error in retrieving the external storage paramters from %s.\n";
+ const char *err15b = "Error in retrieving the external storage parameters from %s.\n";
const char *err16a = "MAXIMUM-DIMENSIONS keyword appears twice in %s.\n";
const char *err16b = "MAXIMUM-DIMENSIONS cannot appear before DIMENSION-SIZES are provided.\n";
const char *err16c = "Error in retrieving the maximum dimension sizes from %s.\n";
@@ -3690,7 +3690,7 @@ static int getCompressionParameter(struct Input *in, FILE *strm)
{
/* currently supports only GZIP */
/* can be extended by adding more values to COMPRESSION-TYPE and */
/* handling the paramters here by adding more cases */
int ival;
const char *err1 = "Unable to get integer value.\n";
@@ -3690,7 +3690,7 @@ static int getCompressionParameter(struct Input *in, FILE *strm)
/* currently supports only GZIP */
/* can be extended by adding more values to COMPRESSION-TYPE and */
- /* handling the paramters here by adding more cases */
+ /* handling the parameters here by adding more cases */
int ival;
const char *err1 = "Unable to get integer value.\n";